@@ -16,9 +16,11 @@ MINUTE_HISTORY_URL = DATA_V2_URL + 'minute'
 COIN_LIST_URL = DATA_URL + 'all/coinlist'
 
 # Social API
-SOCIAL_BASE_URL = DATA_URL + 'social/coin/histo/'
-DAILY_SOCIAL_URL = SOCIAL_BASE_URL + 'day'
-HOURLY_SOCIAL_URL = SOCIAL_BASE_URL + 'hour'
+SOCIAL_BASE_URL = DATA_URL + 'social/coin/'
+SOCIAL_LATEST_URL = SOCIAL_BASE_URL + 'latest'
+SOCIAL_HISTORY_BASE_URL = SOCIAL_BASE_URL + 'histo/'
+DAILY_SOCIAL_URL = SOCIAL_HISTORY_BASE_URL + 'day'
+HOURLY_SOCIAL_URL = SOCIAL_HISTORY_BASE_URL + 'hour'
 
 # Exchange symbols API
 ALL_EXCHANGE_URL = DATA_V3_ALL_URL + 'exchanges'
